#!/bin/bash

# This script is meant to help you take a Yellow Dog Linux 6.2 installation and quickly install
# everything zerogame requires to be up and running. This script is in constant flux and is not
# meant to be used in a stable environment yet.

# Version 0.52
# By Jason Carter (jay@zerojay.com)

if [ $(whoami) != "root" ]; then
  echo "ERROR: You must be the root user to run the Zerogame installation script."
  echo -e '\n'
  exit 67
fi  

if [ `pwd` != "/root/zginstall" ]; then
  echo "ERROR: The Zerogame installation package must be extracted to the /root/ "
  echo "directory per the Readme instructions to properly create a /root/zginstall/ "
  echo "directory to run the installation script from."
  echo -e '\n'
  exit 67
fi  

clear

# User introduction to Zerogame.

echo -e '\n'
echo "Zerogame Installer v0.52" 
echo "By zerojay (jay@zerojay.com)"
echo -e '\n'
echo "Introduction to Zerogame"
echo "Welcome to Zerogame, a script that makes converting your Yellow Dog Linux 6.2 "
echo "install into an emulation heaven quick and simple. First, the installer will "
echo "make some basic repository changes that are required before installation. "
echo "Afterwards, you will be able to configure which emulators will be installed and "
echo "more."
echo -e '\n'
echo "WARNING: Zerogame uses some unsafe network settings for ease-of-use, so if "
echo "connected to the Internet past the initial install, it should ONLY be used "
echo "behind a router w/ its own firewall on a personal LAN to avoid any possible "
echo "security risks."
echo -e '\n'
echo "Press the Enter key when you are ready to proceed with installation or press "
read -p "CTRL-C to exit."

# Update repos and mirrorlists.

echo -e '\n'
cp -R ./configs/yum/* /etc/yum.repos.d/
yum -y clean all
echo -e '\n'

# Add zerogame user if it doesn't exist and remove password.

if [ ! `id -u zerogame` ]; then
	useradd zerogame
	passwd -d zerogame
fi

clear

# User introduction to Bluetooth pairing.

echo -e '\n'
echo "Bluetooth Pairing Information"
echo "For pairing SIXAXIS or DUALSHOCK3 controllers, if selecting yes to the "
echo "following question, please wait until you see the notification that the "
echo "Bluetooth HID daemon has started before pressing the PlayStation button on "
echo "your controllers. The controllers are successfully paired when a notification "
echo "for each controller shows up on the screen."
echo "Pairing mode will last 30 seconds, after which installation will continue."
echo "Note: Only two controllers can be used wirelessly at the same time. You can, "
echo "however, plug in two more controllers through USB if you wish."
echo -e '\n'

# Step 4: Pairing Bluetooth controllers.

while true; do
    echo "Do you wish to use a SIXAXIS/DUALSHOCK3 controller wirelessly through "
    read -n1 -p "Bluetooth? [y/n] " blueans
    echo -e '\n'
    case $blueans in
	[Yy]* )
	  echo -e '\n'

	  # Ask user if they would like to use Bluetooth.
	  # If not, disable Bluetooth services too.
	  # If so, stop the hidd daemon and start it manually.
	  # Ask user to pair controllers.
	 
	  echo "Pairing SIXAXIS/DUALSHOCK3 controllers via Bluetooth... turn on your "
          echo "controllers with the PlayStation button when the Bluetooth HID daemon message "
          echo "shows up below."
	  
	  service hidd stop
	  sleep 2
	  hidd --server --nocheck -n &
	  sleep 30
	  killall hidd
	  echo "Pairing SIXAXIS/DUALSHOCK3 controllers via Bluetooth... done."
	  
	  chkconfig --level 2345 bluetooth on
	  chkconfig --level 2345 hidd on
	  echo "Reenabling the Bluetooth HID daemon..."
	  
	  service hidd start
	  echo "Reenabling the Bluetooth HID daemon... done."
	  break;;
	[Nn]* )
	  echo "Disabling unneccessary system services... hidd..."
	  
	  chkconfig --level 2345 hidd off
	  echo "Disabling unneccessary system services... hidd... done."
	  echo "Disabling unneccessary system services... bluetooth..."
	  
	  chkconfig --level 2345 bluetooth off
	  echo "Disabling unneccessary system services... bluetooth... done."
          break;;
        * ) 
          echo -e "\nPlease answer yes or no.";;
    esac
done
echo -e '\n'
echo -e '\n'


# Step 5a: Ask user of they want Zerogame to autologin after YDL boot or do manual 
# logins/reboots (mainly only if YDL is wanted to be used for other purposes). 

echo "Zerogame can autolaunch after YDL boots and autoreboot upon exiting (default "
echo "behavior in previous versions). While this is fine if using YDL for Zerogame "
echo "only, if planning to use YDL for other purposes than Zerogame (or if you just "
echo "don't want the autolaunching/autorebooting functionality), that may not be the "
echo "desired behavior."
echo "WARNING 1: NON-AUTOLOGIN WILL ONLY WORK ON A FRESH INSTALL OF ZEROGAME. This "
echo "script will not undo the autologin setup from a previous Zerogame install."
echo "WARNING 2: YDL is not designed to be regularly used in under 720p resolution "
echo "unless in text-mode only, so it is recommended to choose Yes to this option if "
echo "limited to 480i/p or 576i/p (selecting No in this case is untested)."
echo -e '\n'
while true; do
    echo "Would you like Zerogame to autolaunch after boot (N requires manual "
    read -n1 -p "logins/reboots)? [y/n] " zgautologin
    case $zgautologin in
	[Yy]* )
          zgautologin="1"
          break;;
        [Nn]* )
          zgautologin="0"
          break;;
        * ) echo -e "\nPlease answer yes or no.";;
    esac
done
echo -e '\n'


# Step 5b: Disable useless/annoying servers on both runlevel 3 and 5 if autolaunch is enabled.

if [ "$zgautologin" = "1" ]; then
echo "Disabling unnecessary system services..."
echo "Errors seen in this section are non-fatal and nothing to worry about."

chkconfig --level 2345 atd off
chkconfig --level 2345 avahi-daemon off
chkconfig --level 2345 anacron off 
chkconfig --level 2345 cpuspeed off 
chkconfig --level 2345 cups off 
chkconfig --level 2345 hplip off 
chkconfig --level 2345 ip6tables off 
chkconfig --level 2345 iptables off  
chkconfig --level 2345 isdn off 
chkconfig --level 2345 mdmonitor off
chkconfig --level 2345 nfslock off
chkconfig --level 2345 pcscd off 
chkconfig --level 2345 restorecond off 
chkconfig --level 2345 gpm off 
chkconfig --level 2345 rpcgssd off 
chkconfig --level 2345 rpcidmapd off 
chkconfig --level 2345 sendmail off 
chkconfig --level 2345 yum-updatesd off
chkconfig --level 2345 auditd off 

echo "Disabling unnecessary system services... done."
echo -e '\n'
echo -e '\n'
fi

# Step 5c: Replace possibly broken /sbin/hwclock installed by yum update.

cp ./configs/ydl/hwclock /sbin/hwclock

# Step 5d: Replace /etc/nsswitch.conf w/ version that allows resolving 
# Windows NetBIOS names.

cp ./configs/ydl/nsswitch.conf /etc/nsswitch.conf

# Step X: Download and set up proper alsa.cards.
# Possibly unneeded now (except if trying to use w/ YDL 6.1)?

#echo "Installing ALSA sound configuration for PlayStation 3 Linux..."

#cp ./configs/alsa/PS3.conf /etc/alsa/cards/PS3.conf
#mkdir /usr/share/alsa/cards/
#cp ./configs/alsa/PS3.conf /usr/share/alsa/cards/PS3.conf
#echo "Installing ALSA sound configuration for PlayStation 3 Linux... done."

# Step 6: Set up gamefiles and music folders on PS3 HD to make sure they're 
# there if needed.

  # Recreate zerogame user folder in case user deleted it to reinstall/upgrade.
  if [ ! -f /home/zerogame/ ]; then
    mkdir -p /home/zerogame/
    chown zerogame:zerogame /home/zerogame/
  fi

mkdir -p /home/zerogame/gamefiles/
mkdir -p /home/zerogame/gamefiles/roms/
mkdir -p /home/zerogame/music/
mkdir -p /home/zerogame/gamefiles/previews/artwork1/
mkdir -p /home/zerogame/gamefiles/previews/artwork2/
mkdir -p /home/zerogame/gamefiles/previews/videos/
chown -R zerogame:zerogame /home/zerogame/gamefiles/
chown -R zerogame:zerogame /home/zerogame/music/

# Step 7: Set up Windows File Sharing.

ipname="0.0.0.0"
sharename="none"
domainname="WORKGROUP"
shareusername="none"
sharepassword=""
unixext="n"

showSAMBAMenu () {
                clear
                echo "-== Windows/SMB File Sharing Setup ==-"
                echo "Edit the information below by pressing the keys indicated on the left."
                echo -e '\n'
		echo "1 - Sharing computer name/IP address: $ipname"
                echo "2 - Share name: $sharename"
		echo "3 - Workgroup/domain: $domainname"
		echo "4 - Username: $shareusername"
		echo "5 - Password: **********"
		echo "6 - Unix Extensions: $unixext"
                echo -e '\n'
		echo "C - Cancel"
		echo "S - Save/Done"
}

echo "Due to the limited space on the PS3 HD when using 10GB allotment for Other OS, "
echo "a Windows-compatible network share (Mac/Linux can do this) can be used in place "
echo "of the /home/zerogame/gamefiles/ folder that normally contains all ROMs, "
echo "artwork and video previews. A static IP address for the computer hosting the "
echo "share may work best, but the NetBIOS name (e.g. 'myname-pc') should also work."
echo "Note: You will have to manually set up the correct folder structure on the "
echo "shared network folder (i.e. 'roms' and 'previews' folders in the Readme)."
echo -e '\n'

while true; do
    echo "Would you like to set up Windows File Sharing (SAMBA) for loading your "
    read -n1 -p "ROMs/previews over your LAN? [y/n] " laninstall
    echo -e '\n'
    case $laninstall in
	[Yy]* )
	  while true; do
		showSAMBAMenu
		read CHOICE
		case "$CHOICE" in
			"1")
						read -p "What is the name or IP address of the computer your ROMs are stored upon? (no slashes) " ipname
						echo -e '\n'
						;;
			"2")
						read -p "What is the name of the shared folder? (e.g. 'myshare' or 'myshare/zg/gamefiles') " sharename
						echo -e '\n'
						;;
			"3")
						read -p "What is the workgroup/domain for $ipname? " domainname
						echo -e '\n'
						;;
			"4")
						read -p "What is a valid username for the computer hosting the share? " shareusername
						echo -e '\n'
						;;
			"5")
						stty -echo
						read -p "What is the password for $shareusername? " sharepassword
						stty echo
						echo -e '\n'
						;;
			"6")
						echo "Is your share on a Linux computer that requires unix extensions turned off?"
						read -n1 -p "If you aren't sure, say N. [y/n] " unixext
						echo -e '\n'
						;;
			[Cc]* )
						break;;
			[Ss]* )
						case $unixext in
							[Yy]* )
									echo "mount.cifs //$ipname/$sharename/ /home/zerogame/gamefiles/ -o user=$shareusername,pass=$sharepassword,domain=$domainname,nounix" >> /etc/rc.local
									break;;
							[Nn]* )
									echo "mount.cifs //$ipname/$sharename/ /home/zerogame/gamefiles/ -o user=$shareusername,pass=$sharepassword,domain=$domainname" >> /etc/rc.local
									echo -e '\n'
									echo "Note: The YDL firewall MUST either be disabled or set to allow SAMBA access"
									echo "if installed in non-autologin mode."
									echo -e '\n'
									break;;
							* ) echo -e "\nPlease answer yes or no.";;
						esac
						break;;
			* )
						echo -e "\nPlease answer using one of the choices listed.";;
	    esac
	  done
	  break;;
	[Nn]* )
	  break;;
	* ) echo -e "\nPlease answer yes or no.";;
    esac
done
echo -e '\n'


# Step 9: Ask user for platforms he/she would like to emulate, then setup folders for and install emulators for those systems.


while true; do
    read -n1 -p "Would you like to install arcade game (MAME) support? [y/n] " mameinstall
    case $mameinstall in
	[Yy]* )
          yumlist="$yumlist sdlmame sdlmame-tools xmame-SDL mame mame-tools"
          mameinstall="1"
          #if [ "$ipname" = "0.0.0.0" ]; then
          	mkdir /home/zerogame/gamefiles/roms/mame/
          	mkdir /home/zerogame/gamefiles/previews/artwork1/mame/
		mkdir /home/zerogame/gamefiles/previews/artwork2/mame/
          	mkdir /home/zerogame/gamefiles/previews/videos/mame/
		echo -e '\n'
          	echo "Note: Please be sure to have at least one valid MAME (v0.136+) romset "
          	echo "in the roms/mame folder before trying to access the ARCADE screen."
          #fi
          break;;
        [Nn]* )
          mameinstall="0"
          break;;
        * ) echo -e "\nPlease answer yes or no.";;
    esac
done
echo -e '\n'

while true; do
    read -n1 -p "Would you like to install Atari Lynx support (requires Lynx BIOS file)? [y/n] " lynxinstall
    case $lynxinstall in
	[Yy]* )
          yumlist="$yumlist mednafen"
	  lynxinstall="1"
	  #if [ "$ipname" = "0.0.0.0" ]; then
	    mkdir /home/zerogame/gamefiles/roms/lynx/
	    mkdir /home/zerogame/gamefiles/previews/artwork1/lynx/
	    mkdir /home/zerogame/gamefiles/previews/artwork2/lynx/
	    mkdir /home/zerogame/gamefiles/previews/videos/lynx/
          #fi
          break;;
      [Nn]* )
        lynxinstall="0"
        break;;
      * ) echo -e "\nPlease answer yes or no.";;
    esac
done
echo -e '\n'

while true; do
    read -n1 -p "Would you like to install Bandai WonderSwan support? [y/n] " wsinstall
    case $wsinstall in
	[Yy]* )
          yumlist="$yumlist mednafen"
	  wsinstall="1"
	  #if [ "$ipname" = "0.0.0.0" ]; then
	    mkdir /home/zerogame/gamefiles/roms/ws/
	    mkdir /home/zerogame/gamefiles/previews/artwork1/ws/
	    mkdir /home/zerogame/gamefiles/previews/artwork2/ws/
	    mkdir /home/zerogame/gamefiles/previews/videos/ws/
          #fi
          break;;
      [Nn]* )
        wsinstall="0"
        break;;
      * ) echo -e "\nPlease answer yes or no.";;
    esac
done
echo -e '\n'

while true; do
    read -n1 -p "Would you like to install Bandai WonderSwan Color support? [y/n] " wscinstall
    case $wscinstall in
	[Yy]* )
          yumlist="$yumlist mednafen"
	  wscinstall="1"
	  #if [ "$ipname" = "0.0.0.0" ]; then
	    mkdir /home/zerogame/gamefiles/roms/wsc/
	    mkdir /home/zerogame/gamefiles/previews/artwork1/wsc/
	    mkdir /home/zerogame/gamefiles/previews/artwork2/wsc/
	    mkdir /home/zerogame/gamefiles/previews/videos/wsc/
          #fi
          break;;
      [Nn]* )
        wscinstall="0"
        break;;
      * ) echo -e "\nPlease answer yes or no.";;
    esac
done
echo -e '\n'

while true; do
    echo "Zerogame also has Commodore 64 (C64) support, but since it is "
    echo "computer emulation, controller behavior will depend on each "
    echo "particular game and may require manual adjustments to settings."
    read -n1 -p "Would you like to install Commodore 64 support? [y/n] " c64install
    case $c64install in
	[Yy]* )
        yumlist="$yumlist vice"
	  c64install="1"
	  #if [ "$ipname" = "0.0.0.0" ]; then
	    mkdir /home/zerogame/gamefiles/roms/c64/
	    mkdir /home/zerogame/gamefiles/previews/artwork1/c64/
	    mkdir /home/zerogame/gamefiles/previews/artwork2/c64/
	    mkdir /home/zerogame/gamefiles/previews/videos/c64/
        #fi
        break;;
    [Nn]* )
      c64install="0"
      break;;
     * ) echo -e "\nPlease answer yes or no.";;
    esac
done
echo -e '\n'

while true; do
    echo "Would you like to install Mattel Intellivision support (requires "
    read -n1 -p "Intellivision BIOS files)? [y/n] " intvinstall
    case $intvinstall in
	[Yy]* )
          yumlist="$yumlist jzintv"
	  intvinstall="1"
	  #if [ "$ipname" = "0.0.0.0" ]; then
	    mkdir /home/zerogame/gamefiles/roms/intv/
	    mkdir /home/zerogame/gamefiles/previews/artwork1/intv/
	    mkdir /home/zerogame/gamefiles/previews/artwork2/intv/
	    mkdir /home/zerogame/gamefiles/previews/videos/intv/
          #fi
          break;;
      [Nn]* )
        intvinstall="0"
        break;;
      * ) echo -e "\nPlease answer yes or no.";;
    esac
done
echo -e '\n'

while true; do
    read -n1 -p "Would you like to install NEC TurboGrafx-16/PC Engine support? [y/n] " tg16install
    case $tg16install in
	[Yy]* )
          yumlist="$yumlist mednafen"
	  tg16install="1"
	  #if [ "$ipname" = "0.0.0.0" ]; then
	    mkdir /home/zerogame/gamefiles/roms/tg16/
	    mkdir /home/zerogame/gamefiles/previews/artwork1/tg16/
	    mkdir /home/zerogame/gamefiles/previews/artwork2/tg16/
	    mkdir /home/zerogame/gamefiles/previews/videos/tg16/
	  #fi
          break;;
      [Nn]* )
        tg16install="0"
        break;;
      * ) echo -e "\nPlease answer yes or no.";;
    esac
done
echo -e '\n'

while true; do
    read -n1 -p "Would you like to install Neo Geo Pocket support? [y/n] " ngpinstall
    case $ngpinstall in
	[Yy]* )
          yumlist="$yumlist mednafen"
	  ngpinstall="1"
	  #if [ "$ipname" = "0.0.0.0" ]; then
	    mkdir /home/zerogame/gamefiles/roms/ngp/
	    mkdir /home/zerogame/gamefiles/previews/artwork1/ngp/
	    mkdir /home/zerogame/gamefiles/previews/artwork2/ngp/
	    mkdir /home/zerogame/gamefiles/previews/videos/ngp/
          #fi
          break;;
      [Nn]* )
        ngpinstall="0"
        break;;
      * ) echo -e "\nPlease answer yes or no.";;
    esac
done
echo -e '\n'

while true; do
    read -n1 -p "Would you like to install Neo Geo Pocket Color support? [y/n] " ngpcinstall
    case $ngpcinstall in
	[Yy]* )
          yumlist="$yumlist mednafen"
	  ngpcinstall="1"
	  #if [ "$ipname" = "0.0.0.0" ]; then
	    mkdir /home/zerogame/gamefiles/roms/ngpc/
	    mkdir /home/zerogame/gamefiles/previews/artwork1/ngpc/
	    mkdir /home/zerogame/gamefiles/previews/artwork2/ngpc/
	    mkdir /home/zerogame/gamefiles/previews/videos/ngpc/
          #fi
          break;;
      [Nn]* )
        ngpcinstall="0"
        break;;
      * ) echo -e "\nPlease answer yes or no.";;
    esac
done
echo -e '\n'

while true; do
    read -n1 -p "Would you like to install Nintendo Entertainment System (NES) support? [y/n] " nesinstall
    case $nesinstall in
	[Yy]* )
          yumlist="$yumlist mednafen"
	  nesinstall="1"
	  #if [ "$ipname" = "0.0.0.0" ]; then
	    mkdir /home/zerogame/gamefiles/roms/nes/
	    mkdir /home/zerogame/gamefiles/previews/artwork1/nes/
	    mkdir /home/zerogame/gamefiles/previews/artwork2/nes/
	    mkdir /home/zerogame/gamefiles/previews/videos/nes/
          #fi
          break;;
      [Nn]* )
        nesinstall="0"
        break;;
      * ) echo -e "\nPlease answer yes or no.";;
    esac
done
echo -e '\n'

while true; do
    echo "Would you like to install Nintendo Famicom Disk System (FDS) support "
    read -n1 -p "(requires FDS BIOS)? [y/n] " fdsinstall
    case $fdsinstall in
	[Yy]* )
          yumlist="$yumlist mednafen"
	  fdsinstall="1"
	  #if [ "$ipname" = "0.0.0.0" ]; then
	    mkdir /home/zerogame/gamefiles/roms/fds/
	    mkdir /home/zerogame/gamefiles/previews/artwork1/fds/
	    mkdir /home/zerogame/gamefiles/previews/artwork2/fds/
	    mkdir /home/zerogame/gamefiles/previews/videos/fds/
          #fi
          break;;
      [Nn]* )
        fdsinstall="0"
        break;;
      * ) echo -e "\nPlease answer yes or no.";;
    esac
done
echo -e '\n'

while true; do
    read -n1 -p "Would you like to install Nintendo GameBoy support? [y/n] " gbinstall
    case $gbinstall in
	[Yy]* )
          yumlist="$yumlist mednafen"
	  gbinstall="1"
	  #if [ "$ipname" = "0.0.0.0" ]; then
	    mkdir /home/zerogame/gamefiles/roms/gb/
	    mkdir /home/zerogame/gamefiles/previews/artwork1/gb/
	    mkdir /home/zerogame/gamefiles/previews/artwork2/gb/
	    mkdir /home/zerogame/gamefiles/previews/videos/gb/
          #fi
          break;;
      [Nn]* )
        gbinstall="0"
        break;;
      * ) echo -e "\nPlease answer yes or no.";;
    esac
done
echo -e '\n'

while true; do
    read -n1 -p "Would you like to install Nintendo GameBoy Advance support? [y/n] " gbainstall
    case $gbainstall in
	[Yy]* )
          yumlist="$yumlist mednafen"
	  gbainstall="1"
	  #if [ "$ipname" = "0.0.0.0" ]; then
	    mkdir /home/zerogame/gamefiles/roms/gba/
	    mkdir /home/zerogame/gamefiles/previews/artwork1/gba/
	    mkdir /home/zerogame/gamefiles/previews/artwork2/gba/
	    mkdir /home/zerogame/gamefiles/previews/videos/gba/
          #fi
          break;;
      [Nn]* )
        gbainstall="0"
        break;;
      * ) echo -e "\nPlease answer yes or no.";;
    esac
done
echo -e '\n'

while true; do
    read -n1 -p "Would you like to install Nintendo GameBoy Color support? [y/n] " gbcinstall
    case $gbcinstall in
	[Yy]* )
          yumlist="$yumlist mednafen"
	  gbcinstall="1"
	  #if [ "$ipname" = "0.0.0.0" ]; then
	    mkdir /home/zerogame/gamefiles/roms/gbc/
	    mkdir /home/zerogame/gamefiles/previews/artwork1/gbc/
	    mkdir /home/zerogame/gamefiles/previews/artwork2/gbc/
	    mkdir /home/zerogame/gamefiles/previews/videos/gbc/
          #fi
          break;;
      [Nn]* )
        gbcinstall="0"
        break;;
      * ) echo -e "\nPlease answer yes or no.";;
    esac
done
echo -e '\n'

while true; do
    read -n1 -p "Would you like to install Nintendo Super NES (SNES) support? [y/n] " snesinstall
    case $snesinstall in
	[Yy]* )
	  snesinstall="1"
	  #if [ "$ipname" = "0.0.0.0" ]; then
	    mkdir /home/zerogame/gamefiles/roms/snes/
	    mkdir /home/zerogame/gamefiles/previews/artwork1/snes/
	    mkdir /home/zerogame/gamefiles/previews/artwork2/snes/
	    mkdir /home/zerogame/gamefiles/previews/videos/snes/
          #fi
          break;;
      [Nn]* )
        snesinstall="0"
        break;;
      * ) echo -e "\nPlease answer yes or no.";;
    esac
done
echo -e '\n'

while true; do
    read -n1 -p "Would you like to install Sega Genesis/Mega Drive support? [y/n] " geninstall
    case $geninstall in
	[Yy]* )
          geninstall="1"
	  #if [ "$ipname" = "0.0.0.0" ]; then
	    mkdir /home/zerogame/gamefiles/roms/gen/
	    mkdir /home/zerogame/gamefiles/previews/artwork1/gen/
	    mkdir /home/zerogame/gamefiles/previews/artwork2/gen/
	    mkdir /home/zerogame/gamefiles/previews/videos/gen/
	  #fi
        break;;
      [Nn]* )
        geninstall="0"
        break;;
      * ) echo -e "\nPlease answer yes or no.";;
    esac
done
echo -e '\n'

while true; do
    echo "Would you like to install SegaCD/MEGA-CD support (requires "
    read -n1 -p "SegaCD BIOS)? [y/n] " segacdinstall
    case $segacdinstall in
	[Yy]* )
          segacdinstall="1"
	  #if [ "$ipname" = "0.0.0.0" ]; then
	    mkdir /home/zerogame/gamefiles/roms/segacd/
	    mkdir /home/zerogame/gamefiles/previews/artwork1/segacd/
	    mkdir /home/zerogame/gamefiles/previews/artwork2/segacd/
	    mkdir /home/zerogame/gamefiles/previews/videos/segacd/
	  #fi
        break;;
      [Nn]* )
        segacdinstall="0"
        break;;
      * ) echo -e "\nPlease answer yes or no.";;
    esac
done
echo -e '\n'

while true; do
    read -n1 -p "Would you like to install Sega Game Gear support? [y/n] " gginstall
    case $gginstall in
	[Yy]* )
          yumlist="$yumlist mednafen"
	  gginstall="1"
	  #if [ "$ipname" = "0.0.0.0" ]; then
	    mkdir /home/zerogame/gamefiles/roms/gg/
	    mkdir /home/zerogame/gamefiles/previews/artwork1/gg/
	    mkdir /home/zerogame/gamefiles/previews/artwork2/gg/
	    mkdir /home/zerogame/gamefiles/previews/videos/gg/
          #fi
          break;;
      [Nn]* )
        gginstall="0"
        break;;
      * ) echo -e "\nPlease answer yes or no.";;
    esac
done
echo -e '\n'

while true; do
    read -n1 -p "Would you like to install Sega Master System support? [y/n] " smsinstall
    case $smsinstall in
	[Yy]* )
          yumlist="$yumlist mednafen"
	  smsinstall="1"
	  #if [ "$ipname" = "0.0.0.0" ]; then
	    mkdir /home/zerogame/gamefiles/roms/sms/
	    mkdir /home/zerogame/gamefiles/previews/artwork1/sms/
	    mkdir /home/zerogame/gamefiles/previews/artwork2/sms/
	    mkdir /home/zerogame/gamefiles/previews/videos/sms/
          #fi
          break;;
      [Nn]* )
        smsinstall="0"
        break;;
      * ) echo -e "\nPlease answer yes or no.";;
    esac
done
echo -e '\n'

#while true; do
#    read -n1 -p "Would you like to install TV Show support? [y/n] " tvinstall
#    case $tvinstall in
#	 [Yy]* )
#          yumlist="$yumlist vlc"
#	   tvinstall="1"
#	   #if [ "$ipname" = "0.0.0.0" ]; then
#	     mkdir /home/zerogame/gamefiles/previews/artwork1/tv/
#            mkdir /home/zerogame/gamefiles/previews/artwork2/tv/
#            mkdir /home/zerogame/gamefiles/previews/videos/tv/
#          #fi
#          break;;
#        [Nn]* )
#          tvinstall="0"
#          break;;
#        * ) echo -e "\nPlease answer yes or no.";;
#    esac
#done
#echo -e '\n'

#while true; do
#    read -n1 -p "Would you like to install Movies support? [y/n] " moviesinstall
#    case $moviesinstall in
#	 [Yy]* )
#          yumlist="$yumlist vlc"
#          moviesinstall="1"
#	   #if [ "$ipname" = "0.0.0.0" ]; then
#             mkdir /home/zerogame/gamefiles/previews/artwork1/movies/
#             mkdir /home/zerogame/gamefiles/previews/artwork2/movies/
#             mkdir /home/zerogame/gamefiles/previews/videos/movies/
#          #fi
#          break;;
#        [Nn]* )
#          moviesinstall="0"
#          break;;
#        * ) echo -e "\nPlease answer yes or no.";;
#    esac
#done
#echo -e '\n'

# Make sure zerogame user has all proper permissions before continuing.
echo "Fixing up permissions before install... "
chown -R zerogame:zerogame /home/zerogame/
echo "Fixing up permissions before install... done."
echo -e '\n'

sleep 3

# Default installation list.
# Additions to 0.52: Slight delay added before and after this step due to 
# unknown issue of yum possibly not installing everything it should. Also 
# added SDL update (since most SDL apps are built on newer version) and p7zip 
# (so that user can extract data from .7z archives).

yumlist="$yumlist SDL fscaler pygame xorg-x11-utils gstreamer-plugins-good gstreamer-plugins-bad gstreamer-plugins-ugly gstreamer-python fluxbox boost bluez-hcidump p7zip"


echo "Installing console emulators, tools and dependencies.... (may take a while)"
echo "Note: You should see 30+ items installed, or some error may have occurred."
echo -e '\n'

sleep 3

# Much faster to install all in one shot as billb mentioned.

yum -y install $yumlist

# Installing XE seperately as billb hasn't added 2.16.2 official to PS3Bodega repo, so we'll use this one which supports autofill for the moment.  UPDATE (20100713): 2.16.2 is on PS3Bodega, but requires new configs and may not be as stable, so still staying with 2.16.1 for now.

if [ "$geninstall" == "1" ]; then
 yum -y --nogpgcheck localinstall ./packages/xe-2.16.1-2.ydl6.bdg.ppc.rpm
fi

# If XE has already been installed because the user selected Genesis support, don't bother wasting time/bandwidth redownloading/reinstalling for SegaCD as well.
if [ "$segacdinstall" == "1" ]; then
 if [ "$geninstall" == "0" ]; then
    yum -y --nogpgcheck localinstall ./packages/xe-2.16.1-2.ydl6.bdg.ppc.rpm
 fi
fi

# Installing snes95-gtk 1.51 separately as updated version (as of 20100713) on PS3Bodega may not work correctly w/ Zerogame's setup (config change???).

if [ "$snesinstall" == "1" ]; then
 yum -y --nogpgcheck localinstall ./packages/snes9x-gtk-1.51-67.ydl6.bdg.ppc.rpm
fi

echo "Installing console emulators, tools and dependencies... done."

# Step 10: Install Wah!Cade.

 cd /root/zginstall/packages/
 tar zxvf wahcade-0.99pre8.tar.gz
 cd /root/zginstall/packages/wahcade/
 echo "Installing Wah!Cade... "

 ./install

 echo "Installing Wah!Cade... done."
 cd /root/zginstall/patches/
 
 # Patch constants.py to allow alternative sound sources such as .MOD files
 # as well as more video formats, including FLV.
 cp constants.py /usr/local/share/wahcade/

 # Patch filters.py to remove restriction on MAME previews.
 cp filters.py /usr/local/share/wahcade/

 # Patch win_main.py to STOP background music instead of pause when launching 
 # games (frees up audio system resources).
 cp win_main.py /usr/local/share/wahcade/

 cd /root/zginstall/packages/
 tar zxvf gizmo-install.tar.gz -C /
 cd /root/zginstall/
 cp ./configs/gizmod/000-CatchZerogame.py /etc/gizmod/modules.d/
 cp ./configs/gizmod/GizmoDeviceStrings.py /etc/gizmod/
 cp -R ./sfx/ /home/zerogame/
 chown -R zerogame:zerogame /home/zerogame/sfx/ 
 
 echo "Installing configuration files and layouts... "
 
 # cd /root/zginstall/

 mkdir /home/zerogame/.fluxbox/
 cp -R ./configs/fluxbox/* /home/zerogame/.fluxbox/
 chown -R zerogame:zerogame /home/zerogame/.fluxbox/
 
 mkdir -p /home/zerogame/.wahcade/
 mkdir -p /home/zerogame/.wahcade/ini/
 mkdir -p /home/zerogame/.wahcade/files/
 mkdir -p /home/zerogame/.wahcade/layouts/
 mkdir -p /home/zerogame/.wahcade/layouts/retrogame-1080p/
 mkdir -p /home/zerogame/.wahcade/layouts/retrogame-1080pb/
 mkdir -p /home/zerogame/.wahcade/layouts/retrogame-720p/
 mkdir -p /home/zerogame/.wahcade/layouts/retrogame-720pb/
 mkdir -p /home/zerogame/.wahcade/layouts/retrogame-480p/
 mkdir -p /home/zerogame/.wahcade/layouts/retrogame-576p/
 mkdir -p /home/zerogame/.wahcade/ctrlr/
 mkdir -p /home/zerogame/.zerogame/

 cp ./configs/wahcade/ctrlr/* /home/zerogame/.wahcade/ctrlr/
 cp ./configs/wahcade/cpviewer.ini /home/zerogame/.wahcade/
 cp ./configs/wahcade/histview.ini /home/zerogame/.wahcade/
 cp ./configs/wahcade/wahcade.ini /home/zerogame/.wahcade/ 

 
 if [ "$geninstall" -eq 1 ]; then 
  cp -R ./configs/xe-nocd/ /home/zerogame/.xe/
  #cp -R ./configs/xe-nocd/ /home/zerogame/.zerogame/
  chown -R zerogame:zerogame /home/zerogame/.xe/
  chown -R zerogame:zerogame /home/zerogame/.zerogame/
  cp ./configs/wahcade/ini/gen.ini /home/zerogame/.wahcade/ini/gen.ini
  cp ./configs/wahcade/ini/gen-0.ini /home/zerogame/.wahcade/ini/gen-0.ini
  cp ./backgrounds/retrogame-1080p/retrogame1080pgen.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./backgrounds/retrogame-1080pb/retrogame1080pbgen.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./backgrounds/retrogame-720p/retrogame720pgen.png /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./backgrounds/retrogame-720pb/retrogame720pbgen.png /home/zerogame/.wahcade/layouts/retrogame-720pb/
  cp ./backgrounds/retrogame-480p/retrogame480pgen.png /home/zerogame/.wahcade/layouts/retrogame-480p/
  cp ./backgrounds/retrogame-576p/retrogame576pgen.png /home/zerogame/.wahcade/layouts/retrogame-576p/
  cp ./layouts/retrogame-1080p/gen.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-1080pb/gen.lay /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./layouts/retrogame-720p/gen.lay /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./layouts/retrogame-720pb/gen.lay /home/zerogame/.wahcade/layouts/retrogame-720pb/
  cp ./layouts/retrogame-480p/gen.lay /home/zerogame/.wahcade/layouts/retrogame-480p/
  cp ./layouts/retrogame-576p/gen.lay /home/zerogame/.wahcade/layouts/retrogame-576p/
 fi

 if [ "$nesinstall" -eq 1 ]; then
  cp -R ./configs/mednafen/ /home/zerogame/.mednafen/
  chown -R zerogame:zerogame /home/zerogame/.mednafen/
  cp ./configs/wahcade/ini/nes.ini /home/zerogame/.wahcade/ini/nes.ini
  cp ./configs/wahcade/ini/nes-0.ini /home/zerogame/.wahcade/ini/nes-0.ini
  cp ./backgrounds/retrogame-1080p/retrogame1080pnes.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./backgrounds/retrogame-1080pb/retrogame1080pbnes.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./backgrounds/retrogame-720p/retrogame720pnes.png /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./backgrounds/retrogame-720pb/retrogame720pbnes.png /home/zerogame/.wahcade/layouts/retrogame-720pb/
  cp ./backgrounds/retrogame-480p/retrogame480pnes.png /home/zerogame/.wahcade/layouts/retrogame-480p/
  cp ./backgrounds/retrogame-576p/retrogame576pnes.png /home/zerogame/.wahcade/layouts/retrogame-576p/
  cp ./layouts/retrogame-1080p/nes.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-1080pb/nes.lay /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./layouts/retrogame-720p/nes.lay /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./layouts/retrogame-720pb/nes.lay /home/zerogame/.wahcade/layouts/retrogame-720pb/
  cp ./layouts/retrogame-480p/nes.lay /home/zerogame/.wahcade/layouts/retrogame-480p/
  cp ./layouts/retrogame-576p/nes.lay /home/zerogame/.wahcade/layouts/retrogame-576p/
 fi
 
 if [ "$gbinstall" -eq 1 ]; then
  cp -R ./configs/mednafen/ /home/zerogame/.mednafen/
  chown -R zerogame:zerogame /home/zerogame/.mednafen/
  cp ./configs/wahcade/ini/gb.ini /home/zerogame/.wahcade/ini/gb.ini
  cp ./configs/wahcade/ini/gb-0.ini /home/zerogame/.wahcade/ini/gb-0.ini
  cp ./backgrounds/retrogame-1080p/retrogame1080pgb.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./backgrounds/retrogame-1080pb/retrogame1080pbgb.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./backgrounds/retrogame-720p/retrogame720pgb.png /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./backgrounds/retrogame-720pb/retrogame720pbgb.png /home/zerogame/.wahcade/layouts/retrogame-720pb/
  cp ./backgrounds/retrogame-480p/retrogame480pgb.png /home/zerogame/.wahcade/layouts/retrogame-480p/
  cp ./backgrounds/retrogame-576p/retrogame576pgb.png /home/zerogame/.wahcade/layouts/retrogame-576p/
  cp ./layouts/retrogame-1080p/gb.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-1080pb/gb.lay /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./layouts/retrogame-720p/gb.lay /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./layouts/retrogame-720pb/gb.lay /home/zerogame/.wahcade/layouts/retrogame-720pb/
  cp ./layouts/retrogame-480p/gb.lay /home/zerogame/.wahcade/layouts/retrogame-480p/
  cp ./layouts/retrogame-576p/gb.lay /home/zerogame/.wahcade/layouts/retrogame-576p/
 fi

 if [ "$lynxinstall" -eq 1 ]; then
  cp -R ./configs/mednafen/ /home/zerogame/.mednafen/
  chown -R zerogame:zerogame /home/zerogame/.mednafen/
  cp ./configs/wahcade/ini/lynx.ini /home/zerogame/.wahcade/ini/lynx.ini
  cp ./configs/wahcade/ini/lynx-0.ini /home/zerogame/.wahcade/ini/lynx-0.ini
  cp ./backgrounds/retrogame-1080p/retrogame1080plynx.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./backgrounds/retrogame-1080pb/retrogame1080pblynx.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./backgrounds/retrogame-720p/retrogame720plynx.png /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./backgrounds/retrogame-720pb/retrogame720pblynx.png /home/zerogame/.wahcade/layouts/retrogame-720pb/
  cp ./backgrounds/retrogame-480p/retrogame480plynx.png /home/zerogame/.wahcade/layouts/retrogame-480p/
  cp ./backgrounds/retrogame-576p/retrogame576plynx.png /home/zerogame/.wahcade/layouts/retrogame-576p/
  cp ./layouts/retrogame-1080p/lynx.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-1080pb/lynx.lay /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./layouts/retrogame-720p/lynx.lay /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./layouts/retrogame-720pb/lynx.lay /home/zerogame/.wahcade/layouts/retrogame-720pb/
  cp ./layouts/retrogame-480p/lynx.lay /home/zerogame/.wahcade/layouts/retrogame-480p/
  cp ./layouts/retrogame-576p/lynx.lay /home/zerogame/.wahcade/layouts/retrogame-576p/
 fi
 
 if [ "$gbcinstall" -eq 1 ]; then
  cp -R ./configs/mednafen/ /home/zerogame/.mednafen/
  chown -R zerogame:zerogame /home/zerogame/.mednafen/
  cp ./configs/wahcade/ini/gbc.ini /home/zerogame/.wahcade/ini/gbc.ini
  cp ./configs/wahcade/ini/gbc-0.ini /home/zerogame/.wahcade/ini/gbc-0.ini
  cp ./backgrounds/retrogame-1080p/retrogame1080pgbc.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./backgrounds/retrogame-1080pb/retrogame1080pbgbc.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./backgrounds/retrogame-720p/retrogame720pgbc.png /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./backgrounds/retrogame-720pb/retrogame720pbgbc.png /home/zerogame/.wahcade/layouts/retrogame-720pb/
  cp ./backgrounds/retrogame-480p/retrogame480pgbc.png /home/zerogame/.wahcade/layouts/retrogame-480p/
  cp ./backgrounds/retrogame-576p/retrogame576pgbc.png /home/zerogame/.wahcade/layouts/retrogame-576p/
  cp ./layouts/retrogame-1080p/gbc.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-1080pb/gbc.lay /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./layouts/retrogame-720p/gbc.lay /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./layouts/retrogame-720pb/gbc.lay /home/zerogame/.wahcade/layouts/retrogame-720pb/
  cp ./layouts/retrogame-480p/gbc.lay /home/zerogame/.wahcade/layouts/retrogame-480p/
  cp ./layouts/retrogame-576p/gbc.lay /home/zerogame/.wahcade/layouts/retrogame-576p/
 fi

 if [ "$gbainstall" -eq 1 ]; then
  cp -R ./configs/mednafen/ /home/zerogame/.mednafen/
  chown -R zerogame:zerogame /home/zerogame/.mednafen/
  cp ./configs/wahcade/ini/gba.ini /home/zerogame/.wahcade/ini/gba.ini
  cp ./configs/wahcade/ini/gba-0.ini /home/zerogame/.wahcade/ini/gba-0.ini
  cp ./backgrounds/retrogame-1080p/retrogame1080pgba.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./backgrounds/retrogame-1080pb/retrogame1080pbgba.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./backgrounds/retrogame-720p/retrogame720pgba.png /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./backgrounds/retrogame-720pb/retrogame720pbgba.png /home/zerogame/.wahcade/layouts/retrogame-720pb/
  cp ./backgrounds/retrogame-480p/retrogame480pgba.png /home/zerogame/.wahcade/layouts/retrogame-480p/
  cp ./backgrounds/retrogame-576p/retrogame576pgba.png /home/zerogame/.wahcade/layouts/retrogame-576p/
  cp ./layouts/retrogame-1080p/gba.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-1080pb/gba.lay /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./layouts/retrogame-720p/gba.lay /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./layouts/retrogame-720pb/gba.lay /home/zerogame/.wahcade/layouts/retrogame-720pb/
  cp ./layouts/retrogame-480p/gba.lay /home/zerogame/.wahcade/layouts/retrogame-480p/
  cp ./layouts/retrogame-576p/gba.lay /home/zerogame/.wahcade/layouts/retrogame-576p/
 fi

 if [ "$wsinstall" -eq 1 ]; then
  cp -R ./configs/mednafen/ /home/zerogame/.mednafen/
  chown -R zerogame:zerogame /home/zerogame/.mednafen/
  cp ./configs/wahcade/ini/ws.ini /home/zerogame/.wahcade/ini/ws.ini
  cp ./configs/wahcade/ini/ws-0.ini /home/zerogame/.wahcade/ini/ws-0.ini
  cp ./backgrounds/retrogame-1080p/retrogame1080pws.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./backgrounds/retrogame-1080pb/retrogame1080pbws.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./backgrounds/retrogame-720p/retrogame720pws.png /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./backgrounds/retrogame-720pb/retrogame720pbws.png /home/zerogame/.wahcade/layouts/retrogame-720pb/
  cp ./backgrounds/retrogame-480p/retrogame480pws.png /home/zerogame/.wahcade/layouts/retrogame-480p/
  cp ./backgrounds/retrogame-576p/retrogame576pws.png /home/zerogame/.wahcade/layouts/retrogame-576p/
  cp ./layouts/retrogame-1080p/ws.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-1080pb/ws.lay /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./layouts/retrogame-720p/ws.lay /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./layouts/retrogame-720pb/ws.lay /home/zerogame/.wahcade/layouts/retrogame-720pb/
  cp ./layouts/retrogame-480p/ws.lay /home/zerogame/.wahcade/layouts/retrogame-480p/
  cp ./layouts/retrogame-576p/ws.lay /home/zerogame/.wahcade/layouts/retrogame-576p/
 fi
 
 if [ "$smsinstall" -eq 1 ]; then
  cp -R ./configs/mednafen/ /home/zerogame/.mednafen/
  chown -R zerogame:zerogame /home/zerogame/.mednafen/
  cp ./configs/wahcade/ini/sms.ini /home/zerogame/.wahcade/ini/sms.ini
  cp ./configs/wahcade/ini/sms-0.ini /home/zerogame/.wahcade/ini/sms-0.ini
  cp ./backgrounds/retrogame-1080p/retrogame1080psms.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./backgrounds/retrogame-1080pb/retrogame1080pbsms.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./backgrounds/retrogame-720p/retrogame720psms.png /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./backgrounds/retrogame-720pb/retrogame720pbsms.png /home/zerogame/.wahcade/layouts/retrogame-720pb/
  cp ./backgrounds/retrogame-480p/retrogame480psms.png /home/zerogame/.wahcade/layouts/retrogame-480p/
  cp ./backgrounds/retrogame-576p/retrogame576psms.png /home/zerogame/.wahcade/layouts/retrogame-576p/
  cp ./layouts/retrogame-1080p/sms.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-1080pb/sms.lay /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./layouts/retrogame-720p/sms.lay /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./layouts/retrogame-720pb/sms.lay /home/zerogame/.wahcade/layouts/retrogame-720pb/
  cp ./layouts/retrogame-480p/sms.lay /home/zerogame/.wahcade/layouts/retrogame-480p/
  cp ./layouts/retrogame-576p/sms.lay /home/zerogame/.wahcade/layouts/retrogame-576p/
 fi
 
 if [ "$gginstall" -eq 1 ]; then
  cp -R ./configs/mednafen/ /home/zerogame/.mednafen/
  chown -R zerogame:zerogame /home/zerogame/.mednafen/
  cp ./configs/wahcade/ini/gg.ini /home/zerogame/.wahcade/ini/gg.ini
  cp ./configs/wahcade/ini/gg-0.ini /home/zerogame/.wahcade/ini/gg-0.ini
  cp ./backgrounds/retrogame-1080p/retrogame1080pgg.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./backgrounds/retrogame-1080pb/retrogame1080pbgg.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./backgrounds/retrogame-720p/retrogame720pgg.png /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./backgrounds/retrogame-720pb/retrogame720pbgg.png /home/zerogame/.wahcade/layouts/retrogame-720pb/
  cp ./backgrounds/retrogame-480p/retrogame480pgg.png /home/zerogame/.wahcade/layouts/retrogame-480p/
  cp ./backgrounds/retrogame-576p/retrogame576pgg.png /home/zerogame/.wahcade/layouts/retrogame-576p/
  cp ./layouts/retrogame-1080p/gg.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-1080pb/gg.lay /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./layouts/retrogame-720p/gg.lay /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./layouts/retrogame-720pb/gg.lay /home/zerogame/.wahcade/layouts/retrogame-720pb/
  cp ./layouts/retrogame-480p/gg.lay /home/zerogame/.wahcade/layouts/retrogame-480p/
  cp ./layouts/retrogame-576p/gg.lay /home/zerogame/.wahcade/layouts/retrogame-576p/
 fi

 if [ "$snesinstall" -eq 1 ]; then
  cp -R ./configs/snes9x/ /home/zerogame/.snes9x/
  chown -R zerogame:zerogame /home/zerogame/.snes9x/
  cp ./configs/wahcade/ini/snes.ini /home/zerogame/.wahcade/ini/snes.ini
  cp ./configs/wahcade/ini/snes-0.ini /home/zerogame/.wahcade/ini/snes-0.ini
  cp ./backgrounds/retrogame-1080p/retrogame1080psnes.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./backgrounds/retrogame-1080pb/retrogame1080pbsnes.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./backgrounds/retrogame-720p/retrogame720psnes.png /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./backgrounds/retrogame-720pb/retrogame720pbsnes.png /home/zerogame/.wahcade/layouts/retrogame-720pb/
  cp ./backgrounds/retrogame-480p/retrogame480psnes.png /home/zerogame/.wahcade/layouts/retrogame-480p/
  cp ./backgrounds/retrogame-576p/retrogame576psnes.png /home/zerogame/.wahcade/layouts/retrogame-576p/
  cp ./layouts/retrogame-1080p/snes.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-1080pb/snes.lay /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./layouts/retrogame-720p/snes.lay /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./layouts/retrogame-720pb/snes.lay /home/zerogame/.wahcade/layouts/retrogame-720pb/
  cp ./layouts/retrogame-480p/snes.lay /home/zerogame/.wahcade/layouts/retrogame-480p/
  cp ./layouts/retrogame-576p/snes.lay /home/zerogame/.wahcade/layouts/retrogame-576p/
 fi
 
 if [ "$c64install" -eq 1 ]; then
  cp -R ./configs/vice/ /home/zerogame/.vice/
  chown -R zerogame:zerogame /home/zerogame/.vice/
  cp ./configs/wahcade/ini/c64.ini /home/zerogame/.wahcade/ini/c64.ini
  cp ./configs/wahcade/ini/c64-0.ini /home/zerogame/.wahcade/ini/c64-0.ini
  cp ./backgrounds/retrogame-1080p/retrogame1080pc64.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./backgrounds/retrogame-1080pb/retrogame1080pbc64.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./backgrounds/retrogame-720p/retrogame720pc64.png /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./backgrounds/retrogame-720pb/retrogame720pbc64.png /home/zerogame/.wahcade/layouts/retrogame-720pb/
  cp ./backgrounds/retrogame-480p/retrogame480pc64.png /home/zerogame/.wahcade/layouts/retrogame-480p/
  cp ./backgrounds/retrogame-576p/retrogame576pc64.png /home/zerogame/.wahcade/layouts/retrogame-576p/
  cp ./layouts/retrogame-1080p/c64.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-1080pb/c64.lay /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./layouts/retrogame-720p/c64.lay /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./layouts/retrogame-720pb/c64.lay /home/zerogame/.wahcade/layouts/retrogame-720pb/
  cp ./layouts/retrogame-480p/c64.lay /home/zerogame/.wahcade/layouts/retrogame-480p/
  cp ./layouts/retrogame-576p/c64.lay /home/zerogame/.wahcade/layouts/retrogame-576p/
 fi

 if [ "$mameinstall" -eq 1 ]; then
  cp -R ./configs/mame/ /home/zerogame/.mame/
  cp ./configs/mame/cfg/*.cfg /home/zerogame/.mame/cfg/
  cp ./configs/mame/cfg/default.cfg /home/zerogame/.mame/cfg/default.cfg
  cp -R ./configs/xmame/ /home/zerogame/.xmame/
  chown -R zerogame:zerogame /home/zerogame/.mame/
  chown -R zerogame:zerogame /home/zerogame/.xmame/
  cp ./configs/wahcade/ini/mame.ini /home/zerogame/.wahcade/ini/mame.ini
  cp ./configs/wahcade/ini/mame-0.ini /home/zerogame/.wahcade/ini/mame-0.ini
  cp ./backgrounds/retrogame-1080p/retrogame1080pmame.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./backgrounds/retrogame-1080pb/retrogame1080pbmame.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./backgrounds/retrogame-720p/retrogame720pmame.png /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./backgrounds/retrogame-720pb/retrogame720pbmame.png /home/zerogame/.wahcade/layouts/retrogame-720pb/
  cp ./backgrounds/retrogame-480p/retrogame480pmame.png /home/zerogame/.wahcade/layouts/retrogame-480p/
  cp ./backgrounds/retrogame-576p/retrogame576pmame.png /home/zerogame/.wahcade/layouts/retrogame-576p/
  cp ./layouts/retrogame-1080p/mame.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-1080pb/mame.lay /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./layouts/retrogame-720p/mame.lay /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./layouts/retrogame-720pb/mame.lay /home/zerogame/.wahcade/layouts/retrogame-720pb/
  cp ./layouts/retrogame-480p/mame.lay /home/zerogame/.wahcade/layouts/retrogame-480p/
  cp ./layouts/retrogame-576p/mame.lay /home/zerogame/.wahcade/layouts/retrogame-576p/
 fi
 
 if [ "$segacdinstall" -eq 1 ]; then 
  cp -R ./configs/xe/ /home/zerogame/.xe/
  #cp -R ./configs/xe/ /home/zerogame/.zerogame/
  mkdir /home/zerogame/.xe/bios
  chown -R zerogame:zerogame /home/zerogame/.xe/
  chown -R zerogame:zerogame /home/zerogame/.zerogame/
  cp ./configs/wahcade/ini/segacd.ini /home/zerogame/.wahcade/ini/segacd.ini
  cp ./configs/wahcade/ini/segacd-0.ini /home/zerogame/.wahcade/ini/segacd-0.ini
  cp ./backgrounds/retrogame-1080p/retrogame1080psegacd.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./backgrounds/retrogame-1080pb/retrogame1080pbsegacd.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./backgrounds/retrogame-720p/retrogame720psegacd.png /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./backgrounds/retrogame-720pb/retrogame720pbsegacd.png /home/zerogame/.wahcade/layouts/retrogame-720pb/
  cp ./backgrounds/retrogame-480p/retrogame480psegacd.png /home/zerogame/.wahcade/layouts/retrogame-480p/
  cp ./backgrounds/retrogame-576p/retrogame576psegacd.png /home/zerogame/.wahcade/layouts/retrogame-576p/
  cp ./layouts/retrogame-1080p/segacd.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-1080pb/segacd.lay /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./layouts/retrogame-720p/segacd.lay /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./layouts/retrogame-720pb/segacd.lay /home/zerogame/.wahcade/layouts/retrogame-720pb/
  cp ./layouts/retrogame-480p/segacd.lay /home/zerogame/.wahcade/layouts/retrogame-480p/
  cp ./layouts/retrogame-576p/segacd.lay /home/zerogame/.wahcade/layouts/retrogame-576p/
 fi

 if [ "$wscinstall" -eq 1 ]; then 
  cp -R ./configs/mednafen/ /home/zerogame/.mednafen/
  chown -R zerogame:zerogame /home/zerogame/.mednafen/
  cp ./configs/wahcade/ini/wsc.ini /home/zerogame/.wahcade/ini/wsc.ini
  cp ./configs/wahcade/ini/wsc-0.ini /home/zerogame/.wahcade/ini/wsc-0.ini
  cp ./backgrounds/retrogame-1080p/retrogame1080pwsc.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./backgrounds/retrogame-1080pb/retrogame1080pbwsc.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./backgrounds/retrogame-720p/retrogame720pwsc.png /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./backgrounds/retrogame-720pb/retrogame720pbwsc.png /home/zerogame/.wahcade/layouts/retrogame-720pb/
  cp ./backgrounds/retrogame-480p/retrogame480pwsc.png /home/zerogame/.wahcade/layouts/retrogame-480p/
  cp ./backgrounds/retrogame-576p/retrogame576pwsc.png /home/zerogame/.wahcade/layouts/retrogame-576p/
  cp ./layouts/retrogame-1080p/wsc.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-1080pb/wsc.lay /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./layouts/retrogame-720p/wsc.lay /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./layouts/retrogame-720pb/wsc.lay /home/zerogame/.wahcade/layouts/retrogame-720pb/
  cp ./layouts/retrogame-480p/wsc.lay /home/zerogame/.wahcade/layouts/retrogame-480p/
  cp ./layouts/retrogame-576p/wsc.lay /home/zerogame/.wahcade/layouts/retrogame-576p/
 fi

 if [ "$fdsinstall" -eq 1 ]; then
  cp -R ./configs/mednafen/ /home/zerogame/.mednafen/
  chown -R zerogame:zerogame /home/zerogame/.mednafen/
  cp ./configs/wahcade/ini/fds.ini /home/zerogame/.wahcade/ini/fds.ini
  cp ./configs/wahcade/ini/fds-0.ini /home/zerogame/.wahcade/ini/fds-0.ini
  cp ./backgrounds/retrogame-1080p/retrogame1080pfds.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./backgrounds/retrogame-1080pb/retrogame1080pbfds.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./backgrounds/retrogame-720p/retrogame720pfds.png /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./backgrounds/retrogame-720pb/retrogame720pbfds.png /home/zerogame/.wahcade/layouts/retrogame-720pb/
  cp ./backgrounds/retrogame-480p/retrogame480pfds.png /home/zerogame/.wahcade/layouts/retrogame-480p/
  cp ./backgrounds/retrogame-576p/retrogame576pfds.png /home/zerogame/.wahcade/layouts/retrogame-576p/
  cp ./layouts/retrogame-1080p/fds.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-1080pb/fds.lay /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./layouts/retrogame-720p/fds.lay /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./layouts/retrogame-720pb/fds.lay /home/zerogame/.wahcade/layouts/retrogame-720pb/
  cp ./layouts/retrogame-480p/fds.lay /home/zerogame/.wahcade/layouts/retrogame-480p/
  cp ./layouts/retrogame-576p/fds.lay /home/zerogame/.wahcade/layouts/retrogame-576p/
 fi
 
 if [ "$ngpinstall" -eq 1 ]; then
  cp -R ./configs/mednafen/ /home/zerogame/.mednafen/
  chown -R zerogame:zerogame /home/zerogame/.mednafen/
  cp ./configs/wahcade/ini/ngp.ini /home/zerogame/.wahcade/ini/ngp.ini
  cp ./configs/wahcade/ini/ngp-0.ini /home/zerogame/.wahcade/ini/ngp-0.ini
  cp ./backgrounds/retrogame-1080p/retrogame1080pngp.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./backgrounds/retrogame-1080pb/retrogame1080pbngp.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./backgrounds/retrogame-720p/retrogame720pngp.png /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./backgrounds/retrogame-720pb/retrogame720pbngp.png /home/zerogame/.wahcade/layouts/retrogame-720pb/
  cp ./backgrounds/retrogame-480p/retrogame480pngp.png /home/zerogame/.wahcade/layouts/retrogame-480p/
  cp ./backgrounds/retrogame-576p/retrogame576pngp.png /home/zerogame/.wahcade/layouts/retrogame-576p/
  cp ./layouts/retrogame-1080p/ngp.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-1080pb/ngp.lay /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./layouts/retrogame-720p/ngp.lay /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./layouts/retrogame-720pb/ngp.lay /home/zerogame/.wahcade/layouts/retrogame-720pb/
  cp ./layouts/retrogame-480p/ngp.lay /home/zerogame/.wahcade/layouts/retrogame-480p/
  cp ./layouts/retrogame-576p/ngp.lay /home/zerogame/.wahcade/layouts/retrogame-576p/
 fi
 
 if [ "$ngpcinstall" -eq 1 ]; then
  cp -R ./configs/mednafen/ /home/zerogame/.mednafen/
  chown -R zerogame:zerogame /home/zerogame/.mednafen/
  cp ./configs/wahcade/ini/ngpc.ini /home/zerogame/.wahcade/ini/ngpc.ini
  cp ./configs/wahcade/ini/ngpc-0.ini /home/zerogame/.wahcade/ini/ngpc-0.ini
  cp ./backgrounds/retrogame-1080p/retrogame1080pngpc.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./backgrounds/retrogame-1080pb/retrogame1080pbngpc.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./backgrounds/retrogame-720p/retrogame720pngpc.png /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./backgrounds/retrogame-720pb/retrogame720pbngpc.png /home/zerogame/.wahcade/layouts/retrogame-720pb/
  cp ./backgrounds/retrogame-480p/retrogame480pngpc.png /home/zerogame/.wahcade/layouts/retrogame-480p/
  cp ./backgrounds/retrogame-576p/retrogame576pngpc.png /home/zerogame/.wahcade/layouts/retrogame-576p/
  cp ./layouts/retrogame-1080p/ngpc.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-1080pb/ngpc.lay /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./layouts/retrogame-720p/ngpc.lay /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./layouts/retrogame-720pb/ngpc.lay /home/zerogame/.wahcade/layouts/retrogame-720pb/
  cp ./layouts/retrogame-480p/ngpc.lay /home/zerogame/.wahcade/layouts/retrogame-480p/
  cp ./layouts/retrogame-576p/ngpc.lay /home/zerogame/.wahcade/layouts/retrogame-576p/
 fi
 
 if [ "$tg16install" -eq 1 ]; then
  cp -R ./configs/mednafen/ /home/zerogame/.mednafen/
  chown -R zerogame:zerogame /home/zerogame/.mednafen/
  cp ./configs/wahcade/ini/tg16.ini /home/zerogame/.wahcade/ini/tg16.ini
  cp ./configs/wahcade/ini/tg16-0.ini /home/zerogame/.wahcade/ini/tg16-0.ini
  cp ./backgrounds/retrogame-1080p/retrogame1080ptg16.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./backgrounds/retrogame-1080pb/retrogame1080pbtg16.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./backgrounds/retrogame-720p/retrogame720ptg16.png /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./backgrounds/retrogame-720pb/retrogame720pbtg16.png /home/zerogame/.wahcade/layouts/retrogame-720pb/
  cp ./backgrounds/retrogame-480p/retrogame480ptg16.png /home/zerogame/.wahcade/layouts/retrogame-480p/
  cp ./backgrounds/retrogame-576p/retrogame576ptg16.png /home/zerogame/.wahcade/layouts/retrogame-576p/
  cp ./layouts/retrogame-1080p/tg16.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-1080pb/tg16.lay /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./layouts/retrogame-720p/tg16.lay /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./layouts/retrogame-720pb/tg16.lay /home/zerogame/.wahcade/layouts/retrogame-720pb/
  cp ./layouts/retrogame-480p/tg16.lay /home/zerogame/.wahcade/layouts/retrogame-480p/
  cp ./layouts/retrogame-576p/tg16.lay /home/zerogame/.wahcade/layouts/retrogame-576p/
 fi
 
 if [ "$intvinstall" -eq 1 ]; then
  mkdir -p /usr/local/share/jzintv/rom/
  chmod 777 /usr/local/share/jzintv/rom/
  cp -R ./configs/jzintv/ /home/zerogame/.jzintv/
  chown -R zerogame:zerogame /home/zerogame/.jzintv/
  cp ./configs/wahcade/ini/intv.ini /home/zerogame/.wahcade/ini/intv.ini
  cp ./configs/wahcade/ini/intv-0.ini /home/zerogame/.wahcade/ini/intv-0.ini
  cp ./backgrounds/retrogame-1080p/retrogame1080pintv.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./backgrounds/retrogame-1080pb/retrogame1080pbintv.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./backgrounds/retrogame-720p/retrogame720pintv.png /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./backgrounds/retrogame-720pb/retrogame720pbintv.png /home/zerogame/.wahcade/layouts/retrogame-720pb/
  cp ./backgrounds/retrogame-480p/retrogame480pintv.png /home/zerogame/.wahcade/layouts/retrogame-480p/
  cp ./layouts/retrogame-1080p/intv.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-1080pb/intv.lay /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./layouts/retrogame-720p/intv.lay /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./layouts/retrogame-720pb/intv.lay /home/zerogame/.wahcade/layouts/retrogame-720pb/
  cp ./layouts/retrogame-480p/intv.lay /home/zerogame/.wahcade/layouts/retrogame-480p/
 fi

#  if [ "$tvinstall" -eq 1 ]; then
#   cp -R ./configs/vlc/ /home/zerogame/.vlc/
#   chown -R zerogame:zerogame /home/zerogame/.vlc/
#   cp ./configs/wahcade/ini/tv.ini /home/zerogame/.wahcade/ini/tv.ini
#   cp ./configs/wahcade/ini/tv-0.ini /home/zerogame/.wahcade/ini/tv-0.ini
#   cp ./backgrounds/retrogame-1080p/retrogame1080ptv.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
#   cp ./backgrounds/retrogame-1080pb/retrogame1080pbtv.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
#   cp ./backgrounds/retrogame-720p/retrogame720ptv.png /home/zerogame/.wahcade/layouts/retrogame-720p/
#   cp ./backgrounds/retrogame-720pb/retrogame720pbtv.png /home/zerogame/.wahcade/layouts/retrogame-720pb/
#   cp ./backgrounds/retrogame-480p/retrogame480ptv.png /home/zerogame/.wahcade/layouts/retrogame-480p/
#   cp ./layouts/retrogame-1080p/tv.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
#   cp ./layouts/retrogame-1080pb/tv.lay /home/zerogame/.wahcade/layouts/retrogame-1080pb/
#   cp ./layouts/retrogame-720p/tv.lay /home/zerogame/.wahcade/layouts/retrogame-720p/
#   cp ./layouts/retrogame-720pb/tv.lay /home/zerogame/.wahcade/layouts/retrogame-720pb/
#   cp ./layouts/retrogame-480p/tv.lay /home/zerogame/.wahcade/layouts/retrogame-480p/
#  fi
#  
#  if [ "$moviesinstall" -eq 1 ]; then
#   cp -R ./configs/vlc/ /home/zerogame/.vlc/
#   chown -R zerogame:zerogame /home/zerogame/.vlc/
#   cp ./configs/wahcade/ini/movies.ini /home/zerogame/.wahcade/ini/movies.ini
#   cp ./configs/wahcade/ini/movies-0.ini /home/zerogame/.wahcade/ini/movies-0.ini
#   cp ./backgrounds/retrogame-1080p/retrogame1080pmovies.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
#   cp ./backgrounds/retrogame-1080pb/retrogame1080pbmovies.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
#   cp ./backgrounds/retrogame-720p/retrogame720pmovies.png /home/zerogame/.wahcade/layouts/retrogame-720p/
#   cp ./backgrounds/retrogame-720pb/retrogame720pbmovies.png /home/zerogame/.wahcade/layouts/retrogame-720p/
#   cp ./backgrounds/retrogame-480p/retrogame480pmovies.png /home/zerogame/.wahcade/layouts/retrogame-480p/
#   cp ./layouts/retrogame-1080p/movies.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
#   cp ./layouts/retrogame-1080pb/movies.lay /home/zerogame/.wahcade/layouts/retrogame-1080pb/
#   cp ./layouts/retrogame-720p/movies.lay /home/zerogame/.wahcade/layouts/retrogame-720p/
#   cp ./layouts/retrogame-720pb/movies.lay /home/zerogame/.wahcade/layouts/retrogame-720pb/
#   cp ./layouts/retrogame-480p/movies.lay /home/zerogame/.wahcade/layouts/retrogame-480p/
#  fi
 

 cp ./configs/wahcade/ini/tools.ini /home/zerogame/.wahcade/ini/tools.ini
 cp ./configs/wahcade/ini/tools-0.ini /home/zerogame/.wahcade/ini/tools-0.ini
 cp ./configs/wahcade/files/tools-0.lst /home/zerogame/.wahcade/files/tools-0.lst
 chmod 444 /home/zerogame/.wahcade/files/tools-0.lst
 cp ./backgrounds/retrogame-1080p/retrogame1080ptools.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
 cp ./backgrounds/retrogame-1080pb/retrogame1080pbtools.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
 cp ./backgrounds/retrogame-720p/retrogame720ptools.png /home/zerogame/.wahcade/layouts/retrogame-720p/
 cp ./backgrounds/retrogame-720pb/retrogame720pbtools.png /home/zerogame/.wahcade/layouts/retrogame-720pb/
 cp ./backgrounds/retrogame-480p/retrogame480ptools.png /home/zerogame/.wahcade/layouts/retrogame-480p/
 cp ./backgrounds/retrogame-576p/retrogame576ptools.png /home/zerogame/.wahcade/layouts/retrogame-576p/
 cp ./layouts/retrogame-1080p/tools.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
 cp ./layouts/retrogame-1080pb/tools.lay /home/zerogame/.wahcade/layouts/retrogame-1080pb/
 cp ./layouts/retrogame-720p/tools.lay /home/zerogame/.wahcade/layouts/retrogame-720p/
 cp ./layouts/retrogame-720pb/tools.lay /home/zerogame/.wahcade/layouts/retrogame-720pb/
 cp ./layouts/retrogame-480p/tools.lay /home/zerogame/.wahcade/layouts/retrogame-480p/
 cp ./layouts/retrogame-576p/tools.lay /home/zerogame/.wahcade/layouts/retrogame-576p/

 cp ./configs/udev/50-udev.rules /etc/udev/rules.d/50-udev.rules 
 echo "input:x:600:zerogame" >> /etc/group
 cp -R ./configs/x/dmrc /home/zerogame/.dmrc
 chown zerogame:zerogame /home/zerogame/.dmrc
 chmod 644 /home/zerogame/.dmrc

 echo "Installing configuration files and layouts... done."
 
 echo "Installing scripts... "
 
 mkdir /home/zerogame/.zerogame/tools/
 cp ./tools/* /home/zerogame/.zerogame/tools/

 chmod 755 /home/zerogame/.zerogame/tools/*.sh
 chown -R zerogame:zerogame /home/zerogame/.zerogame/
 cp ./backgrounds/retrogame-1080p/retrogame1080plaunch.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
 cp ./backgrounds/retrogame-1080pb/retrogame1080pblaunch.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
 cp ./backgrounds/retrogame-720p/retrogame720plaunch.png /home/zerogame/.wahcade/layouts/retrogame-720p/
 cp ./backgrounds/retrogame-720pb/retrogame720pblaunch.png /home/zerogame/.wahcade/layouts/retrogame-720pb/
 cp ./backgrounds/retrogame-480p/retrogame480plaunch.png /home/zerogame/.wahcade/layouts/retrogame-480p/
 cp ./backgrounds/retrogame-576p/retrogame576plaunch.png /home/zerogame/.wahcade/layouts/retrogame-576p/
 cp ./backgrounds/retrogame-1080p/retrogame1080poptions.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
 cp ./backgrounds/retrogame-1080pb/retrogame1080pboptions.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
 cp ./backgrounds/retrogame-720p/retrogame720poptions.png /home/zerogame/.wahcade/layouts/retrogame-720p/
 cp ./backgrounds/retrogame-720pb/retrogame720pboptions.png /home/zerogame/.wahcade/layouts/retrogame-720pb/
 cp ./backgrounds/retrogame-480p/retrogame480poptions.png /home/zerogame/.wahcade/layouts/retrogame-480p/
 cp ./backgrounds/retrogame-576p/retrogame576poptions.png /home/zerogame/.wahcade/layouts/retrogame-576p/
 chown -R zerogame:zerogame /home/zerogame/.wahcade/

 echo "Installing scripts... done."
 echo -e '\n'


# Create mameinfo.xml file if arcade support is installed.

if [ $mameinstall = "1" ]; then
 echo "Creating default mameinfo.xml file required by Wah!Cade... (may take 1-2 mins.)"
 mame -listxml > /home/zerogame/.wahcade/files/mameinfo.xml
 chown zerogame:zerogame /home/zerogame/.wahcade/files/mameinfo.xml
 echo "Creating default mameinfo.xml file required by Wah!Cade... done."
 echo -e '\n'
fi

 
# Ask user if they want to use XMAME for certain games specified by the scaler. 

zgusexmame="0"
if [ $mameinstall = "1" ]; then
  echo "Zerogame normally uses (SDL)MAME for arcade game emulation, but an older "
  echo "XMAME v0.80.1 is also installed as an alternate emulator that allows some "
  echo "select titles (currently Mortal Kombat, Mortal Kombat 2, NBA Hangtime, NBA "
  echo "Jam, NHL Open Ice, Street Fighter: The Movie, and WWF Wrestlemania, plus "
  echo "derivatives) to play at all or with better graphics performance, but at the "
  echo "cost of possibly no audio, maybe needing an older romset than what MAME "
  echo "uses, and having to use ESC on a keyboard to exit XMAME."
  echo -e '\n'
  while true; do
    read -n1 -p "Would you like Zerogame to use XMAME overrides for specific titles? [y/n] " zgusexmame
    case $zgusexmame in
	[Yy]* )
          zgusexmame="1"
          break;;
        [Nn]* )
          zgusexmame="0"
          break;;
        * ) echo -e "\nPlease answer yes or no.";;
    esac
  done
  echo -e '\n'
  echo -e '\n'
fi

# Ask user if they want to set up an FTP server to transfer files to the zerogame user folder.

while true; do
    read -n1 -p "Would you like to install a FTP server to manage Zerogame files? [y/n]? " zgftpinstall
    case $zgftpinstall in
	[Yy]* )
	  echo -e '\n'
	  #echo "Fixing up permissions... (may take a while and display warnings if a LAN "
	  #echo "share is already mounted)"
	  #chown -R zerogame:zerogame /home/zerogame/gamefiles/
	  #chown -R zerogame:zerogame /home/zerogame/music/
	  #echo "Fixing up permissions... done."
	  #echo -e '\n'
	  echo "Installing FTP server..."
	  yum -y install vsftpd
	  chkconfig --level 2345 vsftpd on
	  service vsftpd start
	  echo "Installing FTP server... done."
	  echo -e '\n'
	  echo "You should now be able to use your FTP client to login and transfer files "
	  echo "using the following info:"
	  echo
	  echo -e "Username:\tzerogame"
	  echo -e "Password:\t<leave this blank...there is no password for the account>"
	  echo -n -e "IP Address: \t"
	  ifconfig  | grep 'inet addr:'| grep -v '127.0.0.1' | cut -d: -f2 | awk '{ print $1}'
	  echo -e '\n'
	  echo "Note: The YDL firewall MUST either be disabled or set to allow FTP access if "
	  echo "installed in non-autologin mode. Also, your PS3 IP address may change if it is "
	  echo "dynamically assigned from your router instead of static. You can use the "
	  echo "'ifconfig' command from a terminal window/console login to see the 'inet "
	  echo "addr:' line for eth0(wired)/wlan0(wireless) to see the current IP address."
	  echo -e '\n'
          break;;
        [Nn]* )
          break;;
        * ) echo -e "\nPlease answer yes or no.";;
    esac
done
echo -e '\n'


while true; do
    echo "Do you wish to download the free Arcade Ambience mp3s, about 350MB total, for "
    read -n1 -p "use as Wah!Cade background music? [y/n] " mp3ans
    echo -e '\n'
    case $mp3ans in
	[Yy]* )
	    echo "Downloading Arcade Ambience mp3s: arcade.mp3 - 80MB (1/4)..."
	    
	    wget -P /home/zerogame/music/ http://www.zerojay.com/zerogame/arcade.mp3
	    
	    echo "Downloading Arcade Ambience mp3s: arcade.mp3 - 80MB (1/4)... done."
	    echo "Downloading Arcade Ambience mp3s: arcade83.mp3 - 90MB (2/4)..."
	    
	    wget -P /home/zerogame/music/ http://www.zerojay.com/zerogame/arcade83.mp3
	    echo "Downloading Arcade Ambience mp3s: arcade83.mp3 - 90MB (2/4)... done."
	    echo "Downloading Arcade Ambience mp3s: arcade92.mp3 - 92MB (3/4)..."
	    
	    wget -P /home/zerogame/music/ http://www.zerojay.com/zerogame/arcade92.mp3
	    echo "Downloading Arcade Ambience mp3s: arcade92.mp3 - 92MB (3/4)... done."
	    echo "Downloading Arcade Ambience mp3s: arcade86.mp3 - 92MB (4/4)..."
	    
	    wget -P /home/zerogame/music/ http://www.zerojay.com/zerogame/arcade86.mp3
	    echo "Downloading Arcade Ambience mp3s: arcade86.mp3 - 92MB (4/4)... done."
	    
            break;;
	[Nn]* )
	    echo "You can place your own music (see Readme) into /home/zerogame/music/."
            break;;
	* ) echo -e "\nPlease answer yes or no.";;
    esac
done
echo -e '\n'

chown -R zerogame:zerogame /home/zerogame/music/
#chown -R zerogame:zerogame /home/zerogame/


# read -p "Do you want Zerogame to automatically log the games you play to a text file? [y/n] " logans
# echo -e '\n'
# if [ "$logans" == "n" ]; then
#   
#   echo "use_logging=1" >> /home/zerogame/.zerogame/zerogamerc
# else
#   
#   echo "use_logging=0" >> /home/zerogame/.zerogame/zerogamerc
# fi

cp -R ./fonts/* /usr/share/fonts/
fc-cache -f

touch /home/zerogame/.zerogame/zerogamerc
echo "WAHCADETHEME=retrogame" > /home/zerogame/.zerogame/zerogamerc
if [ $zgautologin = "1" ]; then
  echo "ZEROGAMEDEBUG=0" >> /home/zerogame/.zerogame/zerogamerc
fi
if [ $zgautologin = "0" ]; then
  echo "ZEROGAMEDEBUG=1" >> /home/zerogame/.zerogame/zerogamerc
fi
echo "c64install=$c64install" >> /home/zerogame/.zerogame/zerogamerc
echo "tg16install=$tg16install" >> /home/zerogame/.zerogame/zerogamerc
echo "segacdinstall=$segacdinstall" >> /home/zerogame/.zerogame/zerogamerc
echo "ngpcinstall=$ngpcinstall" >> /home/zerogame/.zerogame/zerogamerc
echo "ngpinstall=$ngpinstall" >> /home/zerogame/.zerogame/zerogamerc
echo "mameinstall=$mameinstall" >> /home/zerogame/.zerogame/zerogamerc
echo "gginstall=$gginstall" >> /home/zerogame/.zerogame/zerogamerc
echo "geninstall=$geninstall" >> /home/zerogame/.zerogame/zerogamerc
echo "gbainstall=$gbainstall" >> /home/zerogame/.zerogame/zerogamerc
echo "gbcinstall=$gbcinstall" >> /home/zerogame/.zerogame/zerogamerc
echo "gbinstall=$gbinstall" >> /home/zerogame/.zerogame/zerogamerc
echo "nesinstall=$nesinstall" >> /home/zerogame/.zerogame/zerogamerc
echo "snesinstall=$snesinstall" >> /home/zerogame/.zerogame/zerogamerc
echo "wsinstall=$wsinstall" >> /home/zerogame/.zerogame/zerogamerc
echo "wscinstall=$wscinstall" >> /home/zerogame/.zerogame/zerogamerc
echo "fdsinstall=$fdsinstall" >> /home/zerogame/.zerogame/zerogamerc
echo "lynxinstall=$lynxinstall" >> /home/zerogame/.zerogame/zerogamerc
echo "smsinstall=$smsinstall" >> /home/zerogame/.zerogame/zerogamerc
echo "intvinstall=$intvinstall" >> /home/zerogame/.zerogame/zerogamerc
echo "ZEROGAMEVERSION=52" >> /home/zerogame/.zerogame/zerogamerc
echo "GIZMODENABLE=1" >> /home/zerogame/.zerogame/zerogamerc
echo "CHECKZEROGAMEUPDATES=1" >> /home/zerogame/.zerogame/zerogamerc
echo "USEZEROGAMEMAMELISTING=0" >> /home/zerogame/.zerogame/zerogamerc
echo "ZEROGAMEDYNAMICRES=1" >> /home/zerogame/.zerogame/zerogamerc
if [ $zgusexmame = "1" ]; then
  echo "USEXMAMEHACKS=1" >> /home/zerogame/.zerogame/zerogamerc
fi
if [ $zgusexmame = "0" ]; then
  echo "USEXMAMEHACKS=0" >> /home/zerogame/.zerogame/zerogamerc
fi
echo "USESCALINGEXCEPTIONS=1" >> /home/zerogame/.zerogame/zerogamerc
chown zerogame:zerogame /home/zerogame/.zerogame/zerogamerc
chmod -R 600 /home/zerogame/.zerogame/zerogamerc

# Autologin Zerogame user (if enabled) and copy user configs.

if [ $zgautologin = "1" ]; then
cp ./configs/ydl/inittab /etc/inittab
mv /usr/share/rhgb/large-computer.png /usr/share/rhgb/oldlarge-computer.png
cp ./configs/ydl/large-computer.png /usr/share/rhgb/large-computer.png
fi
cp ./configs/ydl/bash_profile /home/zerogame/.bash_profile
cp ./configs/ydl/xinitrc /home/zerogame/.xinitrc
chown zerogame /home/zerogame/.bash_profile
chown zerogame /home/zerogame/.xinitrc
cp ./configs/ydl/sudoers /etc/sudoers

# Set hcidump to suid root so that we can execute it as
# the zerogame user for the battery life script.
chmod 4755 /usr/sbin/hcidump

cp -R ./backgrounds/ /home/zerogame/.zerogame/
cp -R ./configs/ /home/zerogame/.zerogame/
cp -R ./docs/ /home/zerogame/.zerogame/
cp -R ./fonts/ /home/zerogame/.zerogame/
cp -R ./layouts/ /home/zerogame/.zerogame/
cp -R ./packages/ /home/zerogame/.zerogame/
cp -R ./patches/ /home/zerogame/.zerogame/
cp -R ./sfx/ /home/zerogame/.zerogame/
cp -R ./tools/ /home/zerogame/.zerogame/
cp -R ./wrappers/ /home/zerogame/.zerogame/
chown -R zerogame:zerogame /home/zerogame/.zerogame/
chmod 755 /home/zerogame/.zerogame/tools/*
chmod 755 /home/zerogame/.zerogame/wrappers/*
cp /home/zerogame/.zerogame/docs/*.txt /home/zerogame/
chmod 444 /home/zerogame/changelog.txt
chmod 444 /home/zerogame/zerogamereadme.txt

echo -e '\n'

if [ "$lynxinstall" == "1" ]; then
 echo "Please be aware that since you installed Atari Lynx support, you "
 echo "will need to place a copy of the Atari Lynx BIOS file at "
 echo "/home/zerogame/.mednafen/lynxboot.img for it to work."
 read -p "Press Enter to continue."
 echo -e '\n'
fi

if [ "$intvinstall" == "1" ]; then
 echo "Please be aware that since you installed Intellivision support, you "
 echo "will need to place copies of the Intellivision BIOS files at "
 echo "/usr/local/share/jzintv/rom/(exec.bin and grom.bin) for it to work."
 read -p "Press Enter to continue."
 echo -e '\n'
fi

if [ "$fdsinstall" == "1" ]; then
 echo "Please be aware that since you installed Famicom Disk System (FDS) "
 echo "support, you will need to place a copy of the FDS BIOS file at "
 echo "/home/zerogame/.mednafen/disksys.rom for it to work."
 read -p "Press Enter to continue."
 echo -e '\n'
fi

if [ "$segacdinstall" == "1" ]; then
 echo "Please be aware that since you installed SegaCD support, you will "
 echo "need to place a copy of the SegaCD BIOS file at "
 echo "/home/zerogame/.xe/bios/megacd-u.rom for it to work."
 read -p "Press Enter to continue."
 echo -e '\n'
fi

while true; do
    echo "Congratulations! Your installation of Zerogame should now be complete, but "
    echo "requires a reboot before use. If not using a LAN share or the FTP server to "
    echo "manage your files, you can now copy files to the /home/zerogame/gamefiles/ "
    echo "and /home/zerogame/music/ folders before rebooting."
    read -n1 -p "Do you want to reboot now? [y/n] " rebootans
    case $rebootans in
	[Yy]* )
          reboot
          break;;
        [Nn]* )
          break;;
        * ) echo -e "\nPlease answer yes or no.";;
    esac
done
echo -e '\n'
