#!/bin/bash

# checkbiosfiles.sh
# Part of the Zerogame Project emulation suite for PS3 Linux
# By Jason Carter (jay@zerojay.com)

# Checks to see if needed BIOS files are in the correct  
# locations and copies them from /home/zerogame/ to correct 
# locations if they are there.

echo -e '\n'
echo "This script checks to see if BIOS files are installed "
echo "for console emulators that need them and offers to "
echo "copy them from the /home/zerogame/ folder to the "
echo "proper folder for you."
echo -e '\n'
echo "NOTE: This does not verify that the BIOS files are "
echo "valid...just whether they exist."
echo -e '\n'

if [ -f /home/zerogame/.mednafen/lynxboot.img ]; then
  echo "Atari Lynx BIOS appears to be installed."
else
  if [ -f /home/zerogame/lynxboot.img ]; then
    AVAILZGBIOS="1"
    echo "Atari Lynx BIOS not installed, but available."
  else
    AVAILZGBIOS="0"
    echo "Atari Lynx BIOS (lynxboot.img) not found."
  fi
fi
if [ -f /usr/local/share/jzintv/rom/exec.bin ]; then
  if [ -f /usr/local/share/jzintv/rom/grom.bin ]; then
    echo "Intellivision BIOS appears to be installed."
  else
    if [ -f /home/zerogame/grom.bin ]; then
      AVAILZGBIOS="1"
      echo "Intellivision BIOS not installed, but available."
    else
      echo "Intellivision BIOS (grom.bin) not found."
    fi
  fi
else
  if [ -f /usr/local/share/jzintv/rom/grom.bin ]; then
    if [ -f /home/zerogame/exec.bin ]; then
      AVAILZGBIOS="1"
      echo "Intellivision BIOS not installed, but available."
    else
      echo "Intellivision BIOS (exec.bin) not found."
    fi
  else
    if [ -f /home/zerogame/exec.bin ]; then
      if [ -f /home/zerogame/grom.bin ]; then
        AVAILZGBIOS="1"
        echo "Intellivision BIOS not installed, but available."
      fi
    else
      echo "Intellivision BIOS (exec.bin & grom.bin) not found."
    fi
  fi
fi
if [ -f /home/zerogame/.mednafen/disksys.rom ]; then
  echo "Nintendo FDS BIOS appears to be installed."
else
  if [ -f /home/zerogame/disksys.rom ]; then
    AVAILZGBIOS="1"
    echo "Nintendo FDS BIOS not installed, but available."
  else
    echo "Nintendo FDS BIOS (disksys.rom) not found."
  fi
fi
if [ -f /home/zerogame/.xe/bios/megacd-u.rom ]; then
  echo "SegaCD BIOS appears to be installed."
else
  if [ -f /usr/local/lib/xe/bios/megacd-u.rom ]; then
    echo "SegaCD BIOS appears to be installed."
  else
    if [ -f /home/zerogame/megacd-u.rom ]; then
      AVAILZGBIOS="1"
      echo "SegaCD BIOS not installed, but available."
    else
      echo "SegaCD BIOS (megacd-u.rom) not found."
    fi
  fi
fi

echo -e '\n'

if [ "$AVAILZGBIOS" = "1" ]; then
  echo "Some BIOS files are available in /home/zerogame/, "
  echo "but are not installed."
  while true; do
    read -n1 -p "Do you wish to install available BIOSes? [Y/N] " installzgbios
      echo -e '\n'
      case $installzgbios in
	[Yy]* )
          if [ -f /home/zerogame/.mednafen/lynxboot.img ]; then
            sleep 1
          else
            if [ -f /home/zerogame/lynxboot.img ]; then
              cp /home/zerogame/lynxboot.img /home/zerogame/.mednafen/
              echo "Atari Lynx BIOS copied to /home/zerogame/.mednafen/"
            fi
          fi
          if [ -f /usr/local/share/jzintv/rom/exec.bin ]; then
            sleep 1
          else
            if [ -f /home/zerogame/exec.bin ]; then
              cp /home/zerogame/exec.bin /usr/local/share/jzintv/rom/
              echo "Intellivision BIOS (exec.bin) copied to /usr/local/share/jzintv/rom/"
            fi
          fi
          if [ -f /usr/local/share/jzintv/rom/grom.bin ]; then
            sleep 1
          else
            if [ -f /home/zerogame/grom.bin ]; then
              cp /home/zerogame/grom.bin /usr/local/share/jzintv/rom/
              echo "Intellivision BIOS (grom.bin) copied to /usr/local/share/jzintv/rom/"
            fi
          fi
          if [ -f /home/zerogame/.mednafen/disksys.rom ]; then
            sleep 1
          else
            if [ -f /home/zerogame/disksys.rom ]; then
              cp /home/zerogame/disksys.rom /home/zerogame/.mednafen/
              echo "Nintendo FDS BIOS copied to /home/zerogame/.mednafen/"
            fi
          fi
          if [ -f /home/zerogame/.xe/bios/megacd-u.rom ]; then
            sleep 1
          else
            if [ -f /usr/local/lib/xe/bios/megacd-u.rom ]; then
              sleep 1
            else
              if [ -f /home/zerogame/megacd-u.rom ]; then
                cp /home/zerogame/megacd-u.rom /home/zerogame/.xe/bios/
                echo "SegaCD BIOS copied to /home/zerogame/.xe/bios/"
              fi
            fi
          fi
          break;;
	[Nn]* )
	  echo "Aborted by user."
          sleep 2
          break;;
	* ) echo -e "\nPlease answer yes or no.";;
      esac
  done
else
  echo "No BIOS files found in /home/zerogame/ that are not "
  echo "already installed."
fi
echo -e '\n'
read -p "Press Enter to exit."

