#!/bin/bash

# createmamelist.sh
# Part of the Zerogame Project emulation suite for PS3 Linux
# By Jason Carter (jay@zerojay.com)

# This script is run by zerogame.sh if it sees that /home/zerogame/.wahcade/files/mame-0.lst
# does not exist. What this means to us is that the MAME games list has not yet been created
# by Wahcade. The main reason for the existance of this script is to create the game list
# manually so that we can give some feedback to the user, otherwise they think the long
# indexing time is actually Wahcade crashing and burning.

# FIXME: zerogame.sh and this script assume all users are going to want to install MAME.


cd /home/zerogame/gamefiles/roms/mame/
echo "Counting number of ROMs in MAME directory..."

# Count up the number of zip files in the MAME ROM directory. Use it as an indicator
# of how much more indexing needs to be done still.
NUMFILES=`ls -1 *.zip | wc -l`
echo "Found $NUMFILES MAME ROMs."

# Export MAME's full game info list to a temporary file that we'll need.
mame -listfull > ~/tmpmame.xml
LOOPCOUNT=1

# For each zip file found in the MAME ROM directory, search the MAME game info
# list for the real full name/friendly name of the ROM. Once this is found, write it
# to a new MAME game list in the proper format.

# For the moment, we are not searching and grabbing all the info from the MAME game
# info file that we could. Mainly because I'm lazy and the themes we have so far will
# not use that info yet.
for i in $( ls $1 ); do
   THENAME=`echo $i | sed 's/\.zip//g'`
   MAMENAME=`grep -w ^$THENAME ~/tmpmame.xml | sed 's/"//g' | sed 's/^'$THENAME'//g' | sed 's/^ *//g'`
   if [ ! "$MAMENAME" ]; then
	echo $THENAME >> /home/zerogame/.wahcade/files/mame-notfound.lst
   else
   	echo $THENAME >> /home/zerogame/.wahcade/files/mame-0.lst
   	echo $MAMENAME >> /home/zerogame/.wahcade/files/mame-0.lst
   	echo "" >> /home/zerogame/.wahcade/files/mame-0.lst
   	echo "" >> /home/zerogame/.wahcade/files/mame-0.lst
   	echo "" >> /home/zerogame/.wahcade/files/mame-0.lst
   	echo "" >> /home/zerogame/.wahcade/files/mame-0.lst
   	echo "" >> /home/zerogame/.wahcade/files/mame-0.lst
   	echo "" >> /home/zerogame/.wahcade/files/mame-0.lst
   	echo "" >> /home/zerogame/.wahcade/files/mame-0.lst
   	echo "" >> /home/zerogame/.wahcade/files/mame-0.lst
   	echo "" >> /home/zerogame/.wahcade/files/mame-0.lst
   	echo "" >> /home/zerogame/.wahcade/files/mame-0.lst
   	echo "" >> /home/zerogame/.wahcade/files/mame-0.lst
   	let "PERCENT= 100 * $LOOPCOUNT / $NUMFILES"
   	echo -ne "ROM $LOOPCOUNT of $NUMFILES - $PERCENT % complete\r"
   	# All the tput lines here deal with the placement of the cursor on the screen.
   	# This is so that we can overwrite the current file number with the next...
   	# I think I'm doing this wrong, however... since the actual line of text flickers
   	# like crazy and still isn't all that easy to read. Fix this soon.
   	let "LOOPCOUNT= $LOOPCOUNT + 1"
   fi
done

# We're done, so delete the MAME game info file we created earlier in the script.
rm ~/tmpmame.xml
echo "Completed."
